
function ClassicStreamDropDownMenu_GetStreamName(clubId, stream)
	local streamName = "";
	local streamId = stream.streamId;
	if stream.leadersAndModeratorsOnly then
		streamName = COMMUNITIES_STREAM_FORMAT_LEADERS_AND_MODERATORS_ONLY:format(stream.name);
	else
		streamName = stream.name;
	end

	local r, g, b = Chat_GetCommunitiesChannelColor(clubId, streamId);
	local color = CreateColor(r, g, b);
	streamName = color:WrapTextInColorCode(streamName);

	local localID = ChatFrame_GetCommunitiesChannelLocalID(clubId, streamId);
	if localID and localID ~= 0 then
		streamName = streamName.." "..GRAY_FONT_COLOR:WrapTextInColorCode(COMMUNITIES_STREAM0_CHAT_SHORTCUT_FORMAT:format(localID));
	end

	return streamName;
end

function ClassicStreamDropDownMenu_Initialize(self)
	local clubId = self:GetClassicFrame():GetSelectedClubId();
	if not clubId then
		return;
	end

	local streams = C_Club.GetStreams(clubId);
	CommunitiesUtil.SortStreams(streams);

	local streamToNotificationSetting = CommunitiesUtil.GetStreamNotificationSettingsLookup(clubId);
	local canEditStream = self:GetClassicFrame():GetPrivilegesForClub(clubId).canDestroyStream;
	local info = L_UIDropDownMenu_CreateInfo();
	info.minWidth = 170;
	for i, stream in ipairs(streams) do
		local streamId = stream.streamId;
		info.text = ClassicStreamDropDownMenu_GetStreamName(clubId, stream);

		-- TODO:: Support mention-based notifications once we have support for mentions.
		if streamToNotificationSetting[streamId] == Enum.ClubStreamNotificationFilter.All and
			CommunitiesUtil.DoesCommunityStreamHaveUnreadMessages(clubId, streamId) then
			info.text = info.text.." "..CreateAtlasMarkup("communities-icon-notification", 10, 10);
		end

		info.mouseOverIcon = canEditStream and stream.streamType == Enum.ClubStreamType.Other and "Interface\\WorldMap\\GEAR_64GREY" or nil;
		info.value = streamId;
		info.checked = streamId == L_UIDropDownMenu_GetSelectedValue(self);
		info.func = function(button)
			local gearIcon = button.Icon;
			if button.mouseOverIcon ~= nil and gearIcon:IsMouseOver() then
				self:GetClassicFrame():ShowEditStreamDialog(clubId, streamId);
			else
				local communitiesFrame = self:GetClassicFrame();
				communitiesFrame:SelectStream(communitiesFrame:GetSelectedClubId(), button.value)
			end
		end
		L_UIDropDownMenu_AddButton(info);
	end

	info.mouseOverIcon = nil;

	if self:GetClassicFrame():GetPrivilegesForClub(clubId).canCreateStream and #streams < 50 then
		info.text = GREEN_FONT_COLOR:WrapTextInColorCode(COMMUNITIES_CREATE_CHANNEL);
		info.value = nil;
		info.customCheckIconAtlas = "communities-icon-addchannelplus";
		info.func = function(button)
			self:GetClassicFrame():ShowCreateChannelDialog();
		end
		L_UIDropDownMenu_AddButton(info);
	end

	info.customCheckIconAtlas = nil;

	info.text = COMMUNITIES_NOTIFICATION_SETTINGS;
	info.value = nil;
	info.customCheckIconTexture = "Interface\\WorldMap\\GEAR_64GREY";
	info.func = function(button)
		self:GetClassicFrame():ShowNotificationSettingsDialog(clubId);
	end
	L_UIDropDownMenu_AddButton(info);
end

ClassicStreamDropDownMixin = {}

function ClassicStreamDropDownMixin:OnLoad()
	L_UIDropDownMenu_SetWidth(self, 115);
	self.Text:SetJustifyH("LEFT");
end

function ClassicStreamDropDownMixin:UpdateUnreadNotification()
	local clubId = self:GetClassicFrame():GetSelectedClubId();
	if clubId then
		local ignoreStreamId = self:GetClassicFrame():GetSelectedStreamId();
		self.NotificationOverlay:SetShown(CommunitiesUtil.DoesCommunityHaveOtherUnreadMessages(clubId, ignoreStreamId));
	else
		self.NotificationOverlay:SetShown(false);
	end
end

function ClassicStreamDropDownMixin:GetClassicFrame()
	return self:GetParent();
end

ClassicEditStreamDialogMixin = {}

function ClassicEditStreamDialogMixin:OnLoad()
	self.Description.EditBox:SetScript("OnTabPressed",
		function()
			self.NameEdit:SetFocus()
			end);
	self.Cancel:SetScript("OnClick", function() self:Hide(); PlaySound(SOUNDKIT.IG_MAINMENU_OPTION_CHECKBOX_ON); end);
	self.NameEdit:SetScript("OnTextChanged", function() self:UpdateAcceptButton(); end);
end

function ClassicEditStreamDialogMixin:OnShow()
	local communitiesFrame = self:GetClassicFrame();
	communitiesFrame:RegisterDialogShown(self);
end

function ClassicEditStreamDialogMixin:ShowCreateDialog(clubId)
	self:SetWidth(350);
	self.Description.EditBox:SetWidth(283);
	self.Delete:Hide();
	self.Accept:SetPoint("BOTTOM", -56, 20);
	self.Cancel:SetPoint("BOTTOM", 56, 20);
	self.TitleLabel:SetText(COMMUNITIES_CREATE_CHANNEL);
	self.NameEdit:SetText("");
	self.Description.EditBox:SetText("");
	self.Accept:SetScript("OnClick", function(self)
		local editStreamDialog = self:GetParent();
		local leadersAndModeratorsOnly = editStreamDialog.TypeCheckBox:GetChecked();
		C_Club.CreateStream(clubId, editStreamDialog.NameEdit:GetText(), editStreamDialog.Description.EditBox:GetText(), leadersAndModeratorsOnly);
		editStreamDialog:Hide();
		PlaySound(SOUNDKIT.IG_MAINMENU_OPTION_CHECKBOX_ON);
		end);
	self:Show();
	self.NameEdit:SetFocus();
end

function ClassicEditStreamDialogMixin:ShowEditDialog(clubId, stream)
	self:SetWidth(400);
	self.Description.EditBox:SetWidth(333);
	self.Delete:Show();
	self.Accept:SetPoint("BOTTOM", -111, 20);
	self.Cancel:SetPoint("BOTTOM", 111, 20);
	self.TitleLabel:SetText(COMMUNITIES_EDIT_CHANNEL);
	self.NameEdit:SetText(stream.name);
	self.Description.EditBox:SetText(stream.subject);
	self.TypeCheckBox:SetChecked(stream.leadersAndModeratorsOnly);
	self.Accept:SetScript("OnClick", function(self)
		local editStreamDialog = self:GetParent();
		local leadersAndModeratorsOnly = editStreamDialog.TypeCheckBox:GetChecked();
		C_Club.EditStream(clubId, stream.streamId, editStreamDialog.NameEdit:GetText(), editStreamDialog.Description.EditBox:GetText(), leadersAndModeratorsOnly)
		editStreamDialog:Hide();
		PlaySound(SOUNDKIT.IG_MAINMENU_OPTION_CHECKBOX_ON);
		end);
	self.Delete:SetScript("OnClick", function(self)
		StaticPopup_Show("CONFIRM_DESTROY_COMMUNITY_STREAM", nil, nil, { clubId = clubId, streamId = stream.streamId, });
		self:GetParent():Hide();
		end);
	self:Show();
end

function ClassicEditStreamDialogMixin:UpdateAcceptButton()
	self.Accept:SetEnabled(self.NameEdit:GetText() ~= "");
end

function ClassicEditStreamDialogMixin:GetClassicFrame()
	return self:GetParent();
end

ClassicNotificationSettingsStreamEntryMixin = {};

function ClassicNotificationSettingsStreamEntryMixin:SetStream(clubId, streamId)
	self.clubId = clubId;
	self.streamId = streamId;
end

function ClassicNotificationSettingsStreamEntryMixin:GetStreamId()
	return self.streamId;
end

function ClassicNotificationSettingsStreamEntryMixin:SetFilter(filter)
	if not self.clubId or not self.streamId then
		return;
	end

	self.filter = filter;
	self.ShowNotificationsButton:SetChecked(filter == Enum.ClubStreamNotificationFilter.All);
	self.HideNotificationsButton:SetChecked(filter == Enum.ClubStreamNotificationFilter.None);
end

function ClassicNotificationSettingsStreamEntryMixin:GetFilter()
	return self.filter;
end

ClassicNotificationSettingsDialogMixin = {};

function ClassicNotificationSettingsDialogMixin:OnLoad()
	self.buttonPool = CreateFramePool("BUTTON", self.ScrollFrame.Child, "ClassicNotificationSettingsStreamEntryTemplate");
end

function ClassicNotificationSettingsDialogMixin:OnShow()
	self:GetClassicFrame():RegisterDialogShown(self);
end

function ClassicNotificationSettingsDialogMixin:Refresh()
	self.buttonPool:ReleaseAll();

	local clubId = self:GetSelectedClubId();
	if clubId then
		local clubInfo = C_Club.GetClubInfo(clubId);
		self.ScrollFrame.Child.QuickJoinButton:SetChecked(clubInfo and clubInfo.socialQueueingEnabled);

		local notificationSettings = C_Club.GetClubStreamNotificationSettings(clubId);
		local notificationSettingsLookup = {};
		for i, setting in ipairs(notificationSettings) do
			notificationSettingsLookup[setting.streamId] = setting.filter;
		end

		local scrollHeight = 105;
		local streams = C_Club.GetStreams(clubId);
		CommunitiesUtil.SortStreams(streams);
		local previousEntry = nil;
		for i, stream in ipairs(streams) do
			local button = self.buttonPool:Acquire();
			button:SetStream(clubId, stream.streamId);
			button.StreamName:SetText(stream.name);
			if i == 1 then
				button:SetPoint("TOPLEFT", self.ScrollFrame.Child.Separator, "BOTTOMLEFT");
			else
				button:SetPoint("TOPLEFT", previousEntry, "BOTTOMLEFT");
			end

			button:SetFilter(notificationSettingsLookup[stream.streamId]);
			button:Show();
			scrollHeight = scrollHeight + button:GetHeight();
			previousEntry = button;
		end

		self.ScrollFrame.Child:SetHeight(scrollHeight);
	end
end

function ClassicNotificationSettingsDialogMixin:SaveSettings()
	local clubId = self:GetSelectedClubId();
	if clubId then
		C_Club.SetSocialQueueingEnabled(clubId, self.ScrollFrame.Child.QuickJoinButton:GetChecked());

		local notificationSettings = {};
		for button in self.buttonPool:EnumerateActive() do
			table.insert(notificationSettings, { streamId = button:GetStreamId(), filter = button:GetFilter(), });
		end

		C_Club.SetClubStreamNotificationSettings(clubId, notificationSettings);
	end
end

function ClassicNotificationSettingsDialogMixin:SetAll(filter)
	for button in self.buttonPool:EnumerateActive() do
		button:SetFilter(filter);
	end
end

function ClassicNotificationSettingsDialogMixin:Cancel()
	self:Hide();
end

function ClassicNotificationSettingsDialogMixin:SelectClub(clubId)
	self.clubId = clubId;

	local clubInfo = C_Club.GetClubInfo(clubId);
	local hasQuickJoin = clubInfo and clubInfo.clubType ~= Enum.ClubType.BattleNet;
	self.ScrollFrame.Child.QuickJoinButton:SetShown(hasQuickJoin);
	if hasQuickJoin then
		self.ScrollFrame.Child.SettingsLabel:SetPoint("TOP", 0, -79);
	else
		self.ScrollFrame.Child.SettingsLabel:SetPoint("TOP", 0, -19);
	end

	self.ClassicListDropDownMenu:OnClubSelected();
	self:Refresh();
end

function ClassicNotificationSettingsDialogMixin:GetSelectedClubId()
	return self.clubId;
end

function ClassicNotificationSettingsDialogMixin:GetClassicFrame()
	return self:GetParent();
end

function ClassicMassNotificationsSettingsButton_OnClick(self)
	PlaySound(SOUNDKIT.IG_MAINMENU_OPTION_CHECKBOX_ON);
	self:GetParent():GetParent():GetParent():SetAll(self.filter);
end

function ClassicNotificationSettingsDialogOkayButton_OnClick(self)
	self:GetParent():SaveSettings();
	self:GetParent():Hide();
end

function ClassicNotificationSettingsDialogCancelButton_OnClick(self)
	self:GetParent():Cancel();
end

--[[
ClassicAddToChatMixin = {};

function ClassicAddToChatMixin:OnLoad()
	SquareButton_SetIcon(self, "DOWN");
end

function ClassicAddToChatMixin:SetClubId(clubId)
	self.clubId = clubId;
end

function ClassicAddToChatMixin:GetClubId()
	return self.clubId;
end

function ClassicAddToChatMixin:SetStreamId(streamId)
	self.streamId = streamId;
end

function ClassicAddToChatMixin:GetStreamId()
	return self.streamId;
end

function ClassicAddToChatMixin:OnClick()
	PlaySound(SOUNDKIT.IG_MAINMENU_OPTION_CHECKBOX_ON);
	local clubId = self:GetParent():GetSelectedClubId();
	local streamId = self:GetParent():GetSelectedStreamId();
	if clubId and streamId then
		self:SetClubId(clubId);
		self:SetStreamId(streamId);
		L_ToggleDropDownMenu(nil, nil, self.DropDown, self, 0, 0);
	end
end

function ClassicAddToChatDropDown_Initialize(self, level)
	local clubId = self:GetParent():GetClubId();
	local streamId = self:GetParent():GetStreamId();
	if not clubId or not streamId then
		return;
	end

	local info = L_UIDropDownMenu_CreateInfo();
	info.text = COMMUNITIES_ADD_TO_CHAT_DROP_DOWN_TITLE;
	info.isTitle = true;
	info.notCheckable = true;
	L_UIDropDownMenu_AddButton(info, level);

	local channelName = Chat_GetCommunitiesChannelName(clubId, streamId);
	for i = 1, FCF_GetNumActiveChatFrames() do
		local chatWindow = _G["ChatFrame"..i];
		if chatWindow ~= COMBATLOG then
			local info = L_UIDropDownMenu_CreateInfo();
			local chatTab = _G["ChatFrame"..i.."Tab"];
			info.text = chatTab.Text:GetText();
			info.value = i;
			info.func = function(button)
			if button.checked then
				ChatFrame_RemoveCommunitiesChannel(chatWindow, clubId, streamId);
			else
				ChatFrame_AddNewCommunitiesChannel(i, clubId, streamId);
			end

			chatTab:Click();
			end;

			info.isNotRadio = true;
			info.checked = ChatFrame_ContainsChannel(chatWindow, channelName);
			L_UIDropDownMenu_AddButton(info, level);
		end
	end

	local canCreateChatWindow = FCF_GetNumActiveChatFrames() ~= NUM_CHAT_WINDOWS;
	if canCreateChatWindow then
		local info = L_UIDropDownMenu_CreateInfo();
		info.text = COMMUNITIES_ADD_TO_CHAT_DROP_DOWN_NEW_CHAT_WINDOW;
		info.func = function(button)
		local clubInfo = C_Club.GetClubInfo(clubId);
		local streamInfo = C_Club.GetStreamInfo(clubId, streamId);
		if clubInfo and streamInfo then
			local MAX_COMMUNITY_NAME_LENGTH = 12;
        local MAX_CHAT_TAB_STREAM_NAME_LENGTH = 50; -- Arbitrarily large, since for now we don't want to truncate the stream part.
        local communityPart = ChatFrame_TruncateToMaxLength(clubInfo.name, MAX_COMMUNITY_NAME_LENGTH);
        local streamPart = ChatFrame_TruncateToMaxLength(streamInfo.name, MAX_CHAT_TAB_STREAM_NAME_LENGTH);
        local chatFrameName = COMMUNITIES_NAME_AND_STREAM_NAME:format(communityPart, streamPart);
        local noDefaultChannels = true;
        local frame, chatFrameIndex = FCF_OpenNewWindow(chatFrameName, noDefaultChannels);
        local setEditBoxToChannel = true;
        ChatFrame_AddNewCommunitiesChannel(chatFrameIndex, clubId, streamId, setEditBoxToChannel);
    end
    end;

    info.isNotRadio = true;
    info.notCheckable = true;
    L_UIDropDownMenu_AddButton(info, level);
end

L_UIDropDownMenu_AddSeparator();

local info = L_UIDropDownMenu_CreateInfo();
info.text = COMMUNITIES_ADD_TO_CHAT_DROP_DOWN_CHAT_SETTINGS;
info.func = function()
local CURRENT_CHAT_FRAME_ID = SELECTED_CHAT_FRAME:GetID();
ShowUIPanel(ChatConfigFrame);
ChatConfigCategory_OnClick(ChatConfigCategoryFrameButton3);
end;

info.isNotRadio = true;
info.notCheckable = true;
L_UIDropDownMenu_AddButton(info, level);
end

function ClassicAddToChatDropDown_OnLoad(self)
	L_UIDropDownMenu_Initialize(self, ClassicAddToChatDropDown_Initialize, "MENU");
end

function ClassicAddToChatMixin:GetClassicFrame()
	return self:GetParent();
end

function ClassicAddStreamHighlightTab_OnClick(self)
	if FCF_GetNumActiveChatFrames() ~= NUM_CHAT_WINDOWS then
		local clubId, streamId = C_Cursor.GetCursorCommunitiesStream();
		if clubId and streamId then
			local clubInfo = C_Club.GetClubInfo(clubId);
			local streamInfo = C_Club.GetStreamInfo(clubId, streamId);
			if clubInfo and streamInfo then
				local MAX_COMMUNITY_NAME_LENGTH = 12;
				local MAX_CHAT_TAB_STREAM_NAME_LENGTH = 50; -- Arbitrarily large, since for now we don't want to truncate the stream part.
				local communityPart = ChatFrame_TruncateToMaxLength(clubInfo.name, MAX_COMMUNITY_NAME_LENGTH);
				local streamPart = ChatFrame_TruncateToMaxLength(streamInfo.name, MAX_CHAT_TAB_STREAM_NAME_LENGTH);
				local chatFrameName = COMMUNITIES_NAME_AND_STREAM_NAME:format(communityPart, streamPart);
				local frame, chatFrameIndex = FCF_OpenNewWindow(chatFrameName);
				C_Club.AddClubStreamToChatWindow(clubId, streamId, chatFrameIndex);
				ChatFrame_AddChannel(frame, Chat_GetCommunitiesChannelName(clubId, streamId));
				self:GetParent():Reset();
			end
		end
	end
end

]]--
